simplify.TransactionReview

Package simplify :: Class TransactionReview |
[hide private]
[frames] | no frames]

# Class TransactionReview

source code

    domain.Domain --+
                    |
                   TransactionReview

A TransactionReview object.

Instance Methods | [hide private]
delete(self, *auth_args) Delete this object | source code
update(self, *auth_args) Updates this object | source code
Inherited from `domain.Domain`: `__getitem__`, `__init__`, `__setitem__`, `__str__`, `class_name`, `to_dict`

Static Methods | [hide private]
create(params, *auth_args) Creates an TransactionReview object | source code
list(criteria=None, *auth_args) Retrieve TransactionReview objects. | source code
find(object_id, *auth_args) Retrieve a TransactionReview object from the API | source code

Method Details | [hide private]

### create(params, *auth_args) Static Method | source code
Creates an TransactionReview object Parameters: `params` - a dict of parameters; valid keys are: `auth_args` - an Authentication object used for the API call. If no value is passed the gloabl keys simplify.public_key and simplify.private_key are used. For backwards compatibility the public and private keys may be passed instead of an Authentication object. `private_api_key` - Private key to use for the API call. If `None`, the value of `simplify.private_key` will be used. Returns: a TransactionReview object

### delete(self, *auth_args) | source code
Delete this object Parameters: `auth_args` - an Authentication object used for the API call. If no value is passed the gloabl keys simplify.public_key and simplify.private_key are used. For backwards compatibility the public and private keys may be passed instead of an Authentication object.

### list(criteria=None, *auth_args) Static Method | source code
Retrieve TransactionReview objects. Parameters: `criteria` - a dict of parameters; valid keys are: `auth_args` - an Authentication object used for the API call. If no value is passed the gloabl keys simplify.public_key and simplify.private_key are used. For backwards compatibility the public and private keys may be passed instead of an Authentication object. Returns: an object which contains the list of TransactionReview objects in the <code>list</code> property and the total number of objects available for the given criteria in the <code>total</code> property.

### find(object_id, *auth_args) Static Method | source code
Retrieve a TransactionReview object from the API Parameters: `object_id` - ID of object to retrieve `auth_args` - an Authentication object used for the API call. If no value is passed the gloabl keys simplify.public_key and simplify.private_key are used. For backwards compatibility the public and private keys may be passed instead of an Authentication object. Returns: a TransactionReview object

### update(self, *auth_args) | source code
Updates this object The properties that can be updated: Parameters: `auth_args` - an Authentication object used for the API call. If no value is passed the gloabl keys simplify.public_key and simplify.private_key are used. For backwards compatibility the public and private keys may be passed instead of an Authentication object. Returns: a TransactionReview object.